<template>
    <div class="player-container">
        <div
            @click="handleActive(player)"
            class="player-item"
            v-for="player in playerList"
            :class="{'player-active': player.name == activePlayer.name}"
            :key="player.name"
        >
            <EasyPlayer
                live
                alt="请选择视频监控点"
                :muted="muted"
                :ref="player.name"
                :reconnection="true"
                v-model="player.url"
                :video-title="player.videoTitle"
            ></EasyPlayer>
        </div>
    </div>
</template>

<script>
import EasyPlayer from '@easydarwin/easyplayer'
const headersUrlencoded = {
    'Content-type': 'application/x-www-form-urlencoded',
}
export default {
    name: 'easyPlayer',
    components: {
        EasyPlayer,
    },
    props: {},
    data() {
        return {
            player: null,
            muted: true,
            activePlayer: {
                name: 'easyPlayer-01',
                url: '',
                videoTitle: '',
            },
            url: '',
            playerList: [
                {
                    name: 'easyPlayer-01',
                    url: '',
                    videoTitle: '',
                },
                {
                    name: 'easyPlayer-02',
                    url: '',
                    videoTitle: '',
                },
                {
                    name: 'easyPlayer-03',
                    url: '',
                    videoTitle: '',
                },
                {
                    name: 'easyPlayer-04',
                    url: '',
                    videoTitle: '',
                },
            ],
        }
    },
    methods: {
        getUrlAndPlay(code, title) {
            if (!this.activePlayer.name) {
                this.$message.warning('请选择播放窗口')
                return
            }
            let data = this.qs.stringify({
                code,
                scheme: 'HLS',
            })
            let param = {
                url: '${portal}/biz/catalog/base/point/previewURLs',
                data,
                method: 'post',
                headers: headersUrlencoded,
            }
            this.$http.request(param).then(
                (resp) => {
                    if (resp.data && resp.data.value) {
                        let value = JSON.parse(resp.data.value)
                        this.url = value.url
                        this.activePlayer.videoTitle = title
                        this.activePlayer.url = this.url
                        this.play(this.activePlayer)
                    }
                },
                (error) => {
                    console.log('获取播放地址', error)
                    this.$message({
                        message: '获取播放地址失败，请重试！',
                        type: 'error',
                    })
                }
            )
        },
        play(player) {
            this.$nextTick(() => {
                this.$refs[player.name].play()
            })
        },
        handleActive(player) {
            this.activePlayer = player
        },
    },
}
</script>

<style lang="scss" scoped>
.player-container{
    width: 100%;
    height: 100%;
    display: flex;
    flex-wrap: wrap;
    align-content: flex-start;
    box-sizing: border-box;
    background-color: #333;
}
.player-item{
    width: 50%!important;
    height: 50%!important;
    border: 2px solid #000;
    box-sizing: border-box;
    cursor: pointer;
}
.player-active{
    border: 2px solid #ffcc00;
}
.player-item:nth-of-type(1){
    width: calc(50% - 2px)!important;
    height: calc(50% - 2px)!important;
    margin: 0 2px 2px 0;
}
.player-item:nth-of-type(2){
    height: calc(50% - 2px)!important;
    margin: 0 0 2px 0;
}
.player-item:nth-of-type(3){
    width: calc(50% - 2px)!important;
    margin: 0 2px 0 0;
}
</style>